aboutsummaryrefslogtreecommitdiff
path: root/engines/mads/dialogs.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-01-16 23:51:46 -0500
committerPaul Gilbert2016-01-16 23:51:46 -0500
commitd750c85fc8da4128f1f7e8ddbb9ffbf9e86cf16f (patch)
tree93e5c1b4978c3d8ea967685c2a93ecc36b40b7db /engines/mads/dialogs.h
parentc321a71241a4d01038d404be3eb2ce3a30f42bf0 (diff)
downloadscummvm-rg350-d750c85fc8da4128f1f7e8ddbb9ffbf9e86cf16f.tar.gz
scummvm-rg350-d750c85fc8da4128f1f7e8ddbb9ffbf9e86cf16f.tar.bz2
scummvm-rg350-d750c85fc8da4128f1f7e8ddbb9ffbf9e86cf16f.zip
MADS: Preliminary converstation message generation
Diffstat (limited to 'engines/mads/dialogs.h')
-rw-r--r--engines/mads/dialogs.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/engines/mads/dialogs.h b/engines/mads/dialogs.h
index 0b98fdd535..61ba48034b 100644
--- a/engines/mads/dialogs.h
+++ b/engines/mads/dialogs.h
@@ -190,8 +190,13 @@ public:
void setLineXp(int xp);
/**
- * Show the dialog, and wait until a key or mouse press.
- */
+ * Adds an icon to the dialog
+ */
+ void addIcon(MSprite *frame);
+
+ /**
+ * Show the dialog, and wait until a key or mouse press.
+ */
virtual void show();
};